﻿using System.Collections.Generic;
using System.IO;
using HeuristicLab.CommandLineInterface;
using HeuristicLab.DynamicAssemblyTestApp;
using HeuristicLab.PluginInfrastructure;

namespace HeuristicLab {
  [Command(Description = "Command to run a .hl-file.")]
  class OptimizeCommand : ICommand {
    [Option(Shortcut = "q", Description = "Disables console output.")]
    public bool Quiet { get; set; }

    [Option(Shortcut = "o", Description = "Sets the output directory for the result.")]
    public string Output { get; set; }

    [Value(0)]
    public string Input { get; set; }

    public void Execute() {
      if (Input == null || !File.Exists(Input))
        throw new FileNotFoundException("Path to .hl file empty or wrong!");
      if (Output != null && !Directory.Exists(Output))
        throw new DirectoryNotFoundException("Output directory does not exist!");

      if (Settings.Host != null) {
        Settings.Host.Run(new ApplicationRunner() {
          QuietMode = Quiet,
          AssembliesToLoad = Settings.assemblyInfos,
          StartApplication = new AppTest() {
            InputFilePath = new UniPath(Input),
            OutputPath = new UniPath(Output ?? Input.Replace(Path.GetFileName(Input), ""))
          }
        });
      }
    }
  }
}
